2023-11-23 Version: 1.1.2
- Generated python2 2020-05-10 for quotas.

2023-09-22 Version: 1.1.1
- Generated python2 2020-05-10 for quotas.

2023-09-14 Version: 1.1.0
- Generated python2 2020-05-10 for quotas.

2023-01-06 Version: 1.0.2
- Quota category supported whiteListLabel.

2022-09-05 Version: 1.0.1
- Added quota template service.

2022-08-30 Version: 1.0.0
- Added thresholdType parameter to API related to quota alarm.

